@@ -12,10 +12,15 @@ Usage::
 import sys
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_resource_groups.literals import (
+    GroupConfigurationStatus,
+    GroupFilterName,
+    QueryErrorCode,
+    QueryType,
+    ResourceFilterName,
+    ResourceStatusValue,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -98,7 +103,7 @@ GroupConfigurationTypeDef = TypedDict(
     {
         "Configuration": List["GroupConfigurationItemTypeDef"],
         "ProposedConfiguration": List["GroupConfigurationItemTypeDef"],
-        "Status": Literal["UPDATING", "UPDATE_COMPLETE", "UPDATE_FAILED"],
+        "Status": GroupConfigurationStatus,
         "FailureReason": str,
     },
     total=False,
@@ -129,25 +134,17 @@ ListGroupResourcesItemTypeDef = TypedDict(
 PendingResourceTypeDef = TypedDict("PendingResourceTypeDef", {"ResourceArn": str}, total=False)
 
 QueryErrorTypeDef = TypedDict(
-    "QueryErrorTypeDef",
-    {
-        "ErrorCode": Literal["CLOUDFORMATION_STACK_INACTIVE", "CLOUDFORMATION_STACK_NOT_EXISTING"],
-        "Message": str,
-    },
-    total=False,
+    "QueryErrorTypeDef", {"ErrorCode": QueryErrorCode, "Message": str}, total=False
 )
 
 ResourceIdentifierTypeDef = TypedDict(
     "ResourceIdentifierTypeDef", {"ResourceArn": str, "ResourceType": str}, total=False
 )
 
-ResourceQueryTypeDef = TypedDict(
-    "ResourceQueryTypeDef",
-    {"Type": Literal["TAG_FILTERS_1_0", "CLOUDFORMATION_STACK_1_0"], "Query": str},
-)
+ResourceQueryTypeDef = TypedDict("ResourceQueryTypeDef", {"Type": QueryType, "Query": str})
 
 ResourceStatusTypeDef = TypedDict(
-    "ResourceStatusTypeDef", {"Name": Literal["PENDING"]}, total=False
+    "ResourceStatusTypeDef", {"Name": ResourceStatusValue}, total=False
 )
 
 ResponseMetadata = TypedDict(
@@ -203,10 +200,7 @@ GetTagsOutputTypeDef = TypedDict(
     total=False,
 )
 
-GroupFilterTypeDef = TypedDict(
-    "GroupFilterTypeDef",
-    {"Name": Literal["resource-type", "configuration-type"], "Values": List[str]},
-)
+GroupFilterTypeDef = TypedDict("GroupFilterTypeDef", {"Name": GroupFilterName, "Values": List[str]})
 
 GroupResourcesOutputTypeDef = TypedDict(
     "GroupResourcesOutputTypeDef",
@@ -247,7 +241,7 @@ PaginatorConfigTypeDef = TypedDict(
 )
 
 ResourceFilterTypeDef = TypedDict(
-    "ResourceFilterTypeDef", {"Name": Literal["resource-type"], "Values": List[str]}
+    "ResourceFilterTypeDef", {"Name": ResourceFilterName, "Values": List[str]}
 )
 
 SearchResourcesOutputTypeDef = TypedDict(
